@@ -31,7 +31,7 @@ def get_annotation_complexity(annotation_node: _Annotation) -> int:
             annotation_node = ast.parse(  # type: ignore
                 annotation_node.s,
             ).body[0].value
-        except (SyntaxError, IndexError):
+        except Exception:
             return 1
 
     if isinstance(annotation_node, ast.Subscript):
